@@ -107,11 +107,13 @@ def combine_files(fnames, root, resource_prefix="", rewrite_urls=True):
                         yield chunk
 
 
-def combo_app(root, resource_prefix="", rewrite_urls=True):
+def combo_app(root, resource_prefix="", rewrite_urls=True, additional_headers=None):
     """A simple YUI Combo Service WSGI app.
 
     Serves any files under C{root}, setting an appropriate
     C{Content-Type} header.
+    Additional headers can be provided as a list of tuples to allow
+    for generic extensions, but their correctness won't be verified.
     """
     root = os.path.abspath(root)
 
@@ -139,7 +141,11 @@ def combo_app(root, resource_prefix="", rewrite_urls=True):
             start_response("400 Bad Request", [("Content-Type", content_type)])
             return ("Bad Request",)
         else:
-            start_response("200 OK", [("Content-Type", content_type)])
+            headers = [("Content-Type", content_type),
+                       ("X-Content-Type-Options", "nosniff")]
+            if additional_headers is not None:
+                headers.extend(additional_headers)
+            start_response("200 OK", headers)
 
         return combine_files(fnames, updated_root, resource_prefix,
                              rewrite_urls=rewrite_urls)
